@@ -49,9 +49,12 @@
 
 package com.openexchange.caldav.resources;
 
+import static com.openexchange.chronos.provider.CalendarFolderProperty.USED_FOR_SYNC_LITERAL;
+import static com.openexchange.chronos.provider.CalendarFolderProperty.optPropertyValue;
 import java.util.ArrayList;
 import java.util.List;
 import com.openexchange.caldav.GroupwareCaldavFactory;
+import com.openexchange.caldav.Tools;
 import com.openexchange.caldav.mixins.ScheduleDefaultCalendarURL;
 import com.openexchange.caldav.mixins.ScheduleDefaultTasksURL;
 import com.openexchange.caldav.mixins.ScheduleInboxURL;
@@ -59,12 +62,15 @@ import com.openexchange.caldav.mixins.ScheduleOutboxURL;
 import com.openexchange.caldav.mixins.SupportedCalendarComponentSets;
 import com.openexchange.caldav.mixins.SupportedReportSet;
 import com.openexchange.dav.DAVProtocol;
+import com.openexchange.dav.DAVUserAgent;
 import com.openexchange.dav.Privilege;
 import com.openexchange.dav.mixins.CurrentUserPrivilegeSet;
 import com.openexchange.dav.resources.DAVCollection;
 import com.openexchange.dav.resources.DAVRootCollection;
+import com.openexchange.dav.resources.FolderCollection;
 import com.openexchange.dav.resources.PlaceholderCollection;
 import com.openexchange.exception.OXException;
+import com.openexchange.folderstorage.CalendarFolderConverter;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.FolderResponse;
 import com.openexchange.folderstorage.FolderService;
@@ -72,7 +78,7 @@ import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
-import com.openexchange.folderstorage.database.contentType.CalendarContentType;
+import com.openexchange.folderstorage.calendar.contentType.CalendarContentType;
 import com.openexchange.folderstorage.database.contentType.TaskContentType;
 import com.openexchange.folderstorage.mail.contentType.TrashContentType;
 import com.openexchange.folderstorage.type.PrivateType;
@@ -107,7 +113,7 @@ public class CalDAVRootCollection extends DAVRootCollection {
     /**
      * Initializes a new {@link CalDAVRootCollection}.
      *
-     * @param factory the factory
+     * @param factory The factory
      */
     public CalDAVRootCollection(GroupwareCaldavFactory factory) {
         super(factory, "Calendars");
@@ -137,44 +143,55 @@ public class CalDAVRootCollection extends DAVRootCollection {
 
     @Override
     public DAVCollection getChild(String name) throws WebdavProtocolException {
+        /*
+         * check static paths
+         */
         if (ScheduleOutboxURL.SCHEDULE_OUTBOX.equals(name)) {
             return factory.mixin(new ScheduleOutboxCollection(factory));
-        } else if (ScheduleInboxURL.SCHEDULE_INBOX.equals(name)) {
+        }
+        if (ScheduleInboxURL.SCHEDULE_INBOX.equals(name)) {
             return factory.mixin(new ScheduleInboxCollection(factory));
         }
+        /*
+         * check folder via decoded identifier
+         */
+        try {
+            UserizedFolder folder = getFolder(Tools.decodeFolderId(name));
+            if (matches(name, folder)) {
+                return createCollection(folder);
+            }
+        } catch (OXException | IllegalArgumentException e) {
+            LOG.debug("Unable to get folder by resource name \"{}\", matching against all visible folders as fallback.", name, e);
+        }
+        /*
+         * match against all visible folders; then fall-back to placeholder collection
+         */
         try {
             for (UserizedFolder folder : getSubfolders()) {
-                if (name.equals(folder.getID())) {
-                    LOG.debug("{}: found child collection by name '{}'", this.getUrl(), name);
+                if (matches(name, folder)) {
                     return createCollection(folder);
                 }
-                if (null != folder.getMeta() && folder.getMeta().containsKey("resourceName") && name.equals(folder.getMeta().get("resourceName"))) {
-                    LOG.debug("{}: found child collection by resource name '{}'", this.getUrl(), name);
+                if (DAVUserAgent.THUNDERBIRD_LIGHTNING.equals(getUserAgent()) && matchesLegacy(name, folder)) {
+                    LOG.debug("Resolving legacy resource name {} to folder {} for Thunderbird/Lightning.", name, folder.getID());
                     return createCollection(folder);
                 }
             }
-            LOG.debug("{}: child collection '{}' not found, creating placeholder collection", this.getUrl(), name);
+            LOG.debug("{}: child collection '{}' not found, creating placeholder collection", getUrl(), name);
             return new PlaceholderCollection<CommonObject>(factory, constructPathForChildResource(name), CalendarContentType.getInstance(), getTreeID());
         } catch (OXException e) {
             throw DAVProtocol.protocolException(getUrl(), e);
         }
     }
 
-    private CalDAVFolderCollection<?> createCollection(UserizedFolder folder) throws OXException {
-        if (TaskContentType.getInstance().equals(folder.getContentType())) {
-            return factory.mixin(new TaskCollection(factory, constructPathForChildResource(folder), folder));
-        } else if (CalendarContentType.getInstance().equals(folder.getContentType())) {
-            return factory.mixin(new AppointmentCollection(factory, constructPathForChildResource(folder), folder));
-        } else {
-            throw new UnsupportedOperationException("content type " + folder.getContentType() + " not supported");
-        }
+    private FolderCollection<?> createCollection(UserizedFolder folder) throws OXException {
+        return createCollection(folder, CalDAVFolderCollection.NO_ORDER);
     }
 
-    private CalDAVFolderCollection<?> createCollection(UserizedFolder folder, int order) throws OXException {
+    private FolderCollection<?> createCollection(UserizedFolder folder, int order) throws OXException {
         if (TaskContentType.getInstance().equals(folder.getContentType())) {
             return factory.mixin(new TaskCollection(factory, constructPathForChildResource(folder), folder, order));
         } else if (CalendarContentType.getInstance().equals(folder.getContentType())) {
-            return factory.mixin(new AppointmentCollection(factory, constructPathForChildResource(folder), folder, order));
+            return factory.mixin(new EventCollection(factory, constructPathForChildResource(folder), folder, order));
         } else {
             throw new UnsupportedOperationException("content type " + folder.getContentType() + " not supported");
         }
@@ -201,11 +218,11 @@ public class CalDAVRootCollection extends DAVRootCollection {
     /**
      * Constructs a string representing the WebDAV name for a folder resource.
      *
-     * @param folder the folder to construct the name for
-     * @return the name
+     * @param folder The folder to construct the name for
+     * @return The resource name
      */
     private String constructNameForChildResource(UserizedFolder folder) {
-        return folder.getID();
+        return Tools.encodeFolderId(folder.getID());
     }
 
     private WebdavPath constructPathForChildResource(UserizedFolder folder) {
@@ -216,45 +233,70 @@ public class CalDAVRootCollection extends DAVRootCollection {
      * Gets a list of all visible and subscribed task- and calendar-folders in the configured folder tree.
      *
      * @return The visible folders
-     * @throws FolderException
      */
     private List<UserizedFolder> getVisibleFolders() throws OXException {
         UserPermissionBits permissionBits = ServerSessionAdapter.valueOf(factory.getSession()).getUserPermissionBits();
         List<UserizedFolder> folders = new ArrayList<UserizedFolder>();
         if (permissionBits.hasCalendar()) {
-            folders.addAll(getVisibleFolders(PrivateType.getInstance(), CalendarContentType.getInstance()));
+            folders.addAll(getSynchronizedFolders(PrivateType.getInstance(), CalendarContentType.getInstance()));
             if (permissionBits.hasFullPublicFolderAccess()) {
-                folders.addAll(getVisibleFolders(PublicType.getInstance(), CalendarContentType.getInstance()));
+                folders.addAll(getSynchronizedFolders(PublicType.getInstance(), CalendarContentType.getInstance()));
             }
             if (permissionBits.hasFullSharedFolderAccess()) {
-                folders.addAll(getVisibleFolders(SharedType.getInstance(), CalendarContentType.getInstance()));
+                folders.addAll(getSynchronizedFolders(SharedType.getInstance(), CalendarContentType.getInstance()));
             }
         }
         if (permissionBits.hasTask()) {
-            folders.addAll(getVisibleFolders(PrivateType.getInstance(), TaskContentType.getInstance()));
+            folders.addAll(getSynchronizedFolders(PrivateType.getInstance(), TaskContentType.getInstance()));
         }
         return folders;
     }
 
+    private UserizedFolder getFolder(String folderId) throws OXException {
+        UserizedFolder folder = getFolderService().getFolder(getTreeID(), folderId, factory.getSession(), null);
+        if (false == isUsedForSync(folder)) {
+            throw OXException.notFound(folderId);
+        }
+        return folder;
+    }
+
     /**
-     * Gets a list containing all visible folders of the given {@link Type}.
-     * @param type
-     * @return
-     * @throws FolderException
+     * Gets a list containing all visible and synchronizable folders of the given {@link Type}.
+     *
+     * @param type The type to get the folders for
+     * @param contentType The content type to get the folders for
+     * @return The synchronizable folders, or an empty list if there are none
      */
-    private List<UserizedFolder> getVisibleFolders(Type type, ContentType contentType) throws OXException {
+    private List<UserizedFolder> getSynchronizedFolders(Type type, ContentType contentType) throws OXException {
         List<UserizedFolder> folders = new ArrayList<UserizedFolder>();
         FolderResponse<UserizedFolder[]> visibleFoldersResponse = getFolderService().getVisibleFolders(
                 getTreeID(), contentType, type, false, factory.getSession(), null);
         UserizedFolder[] response = visibleFoldersResponse.getResponse();
         for (UserizedFolder folder : response) {
-            if (Permission.READ_OWN_OBJECTS < folder.getOwnPermission().getReadPermission() && false == isTrashFolder(folder)) {
+            if (isUsedForSync(folder)) {
                 folders.add(folder);
             }
         }
         return folders;
     }
 
+    /**
+     * Gets a value indicating whether the folder should be considered for synchronization with external clients or not.
+     *
+     * @param folder The folder to check
+     * @return <code>true</code> if the folder should be considered for synchronization, <code>false</code>, otherwise
+     */
+    private boolean isUsedForSync(UserizedFolder folder) throws OXException {
+        if (Permission.READ_OWN_OBJECTS > folder.getOwnPermission().getReadPermission()) {
+            return false;
+        }
+        if (isTrashFolder(folder)) {
+            return false;
+        }
+        Object value = optPropertyValue(CalendarFolderConverter.getExtendedProperties(folder), USED_FOR_SYNC_LITERAL);
+        return null == value || Boolean.parseBoolean(String.valueOf(value));
+    }
+
     /**
      * Gets the id of the default trash folder
      *
@@ -322,4 +364,46 @@ public class CalDAVRootCollection extends DAVRootCollection {
         return treeID;
     }
 
+    private static boolean matchesLegacy(String resourceName, UserizedFolder folder) {
+        if (null == resourceName || null == folder || null == folder.getID()) {
+            return false;
+        }
+        /*
+         * try constructed composite identifier
+         */
+        if ((Tools.DEFAULT_ACCOUNT_PREFIX + resourceName).equals(folder.getID())) {
+            return true;
+        }
+        /*
+         * try relative folder identifier as-is as additional fallback
+         */
+        if (resourceName.equals(folder.getID())) {
+            return true;
+        }
+        return false;
+    }
+
+    private static boolean matches(String resourceName, UserizedFolder folder) {
+        if (null == resourceName || null == folder || null == folder.getID()) {
+            return false;
+        }
+        /*
+         * match decoded name first
+         */
+        try {
+            if (Tools.decodeFolderId(resourceName).equals(folder.getID())) {
+                return true;
+            }
+        } catch (IllegalArgumentException e) {
+            LOG.debug("Error decoding child resource name {}, assuming legacy or stored resource name.", resourceName, e);
+        }
+        /*
+         * try via stored resource name, too
+         */
+        if (null != folder.getMeta() && folder.getMeta().containsKey("resourceName") && resourceName.equals(folder.getMeta().get("resourceName"))) {
+            return true;
+        }
+        return false;
+    }
+
 }
