@@ -56,7 +56,7 @@ import java.util.List;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.api2.TasksSQLInterface;
 import com.openexchange.caldav.GroupwareCaldavFactory;
-import com.openexchange.caldav.Patches;
+import com.openexchange.caldav.TaskPatches;
 import com.openexchange.caldav.Tools;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.data.conversion.ical.ConversionWarning;
@@ -81,6 +81,7 @@ public class TaskResource extends CalDAVResource<Task> {
      * All task fields that may be set in iCal files
      */
     private static final int[] CALDAV_FIELDS = {
+        Task.START_DATE, // DTSTART
         Task.END_DATE, // DUE
         Task.TITLE, // SUMMARY
         Task.PRIORITY, // PRIORITY
@@ -111,9 +112,9 @@ public class TaskResource extends CalDAVResource<Task> {
     protected void saveObject() throws OXException {
         Task originalTask = parent.load(object);
         checkForExplicitRemoves(originalTask, taskToSave);
-        Patches.Incoming.adjustTaskStatus(originalTask, taskToSave);
-        Patches.Incoming.adjustTaskStart(originalTask, taskToSave);
-        getTaskInterface().updateTaskObject(taskToSave, parentFolderID, object.getLastModified());
+        TaskPatches.Incoming.adjustTaskStatus(originalTask, taskToSave);
+        TaskPatches.Incoming.adjustTaskStart(originalTask, taskToSave);
+        getTaskInterface().updateTaskObject(taskToSave, getId(parent), object.getLastModified());
         handleAttachments(originalTask, taskToSave);
     }
 
@@ -125,7 +126,7 @@ public class TaskResource extends CalDAVResource<Task> {
     @Override
     protected void createObject() throws OXException {
         taskToSave.removeObjectID(); // in case it's already assigned due to retry operations
-        taskToSave.setParentFolderID(null != object ? object.getParentFolderID() : parentFolderID);
+        taskToSave.setParentFolderID(null != object ? object.getParentFolderID() : getId(parent));
         getTaskInterface().insertTaskObject(taskToSave);
         handleAttachments(null, taskToSave);
     }
@@ -135,7 +136,7 @@ public class TaskResource extends CalDAVResource<Task> {
         final Task task = new Task();
         task.setObjectID(object.getObjectID());
         task.setParentFolderID(Tools.parse(target.getFolder().getID()));
-        getTaskInterface().updateTaskObject(task, parentFolderID, object.getLastModified());
+        getTaskInterface().updateTaskObject(task, getId(parent), object.getLastModified());
     }
 
     @Override
@@ -161,7 +162,7 @@ public class TaskResource extends CalDAVResource<Task> {
                 taskToSave.setObjectID(object.getObjectID());
                 taskToSave.removeUid();
             } else {
-                taskToSave.setParentFolderID(parentFolderID);
+                taskToSave.setParentFolderID(getId(parent));
             }
         }
     }
